@@ -1,7 +1,14 @@
 import pytest
+from sphinx_codeautolink.parse import Component
 from ._util import refs_equal
 
 
+class TestUnit:
+    def test_component_from_unrecognised_ast(self):
+        with pytest.raises(ValueError):
+            Component.from_ast('not ast')
+
+
 class TestSimple:
     @refs_equal
     def test_empty_source(self):
@@ -116,3 +123,9 @@ class TestSimple:
             ('sphinx_codeautolink.setup', 'setup')
         ]
         return s, refs
+
+    @refs_equal
+    def test_import_star_invalid(self):
+        s = 'from not_a_module import *'
+        refs = [('not_a_module', 'not_a_module')]
+        return s, refs
