@@ -11,6 +11,12 @@ class TestFunction:
         refs = [('a', 'a'), ('a', 'a')]
         return s, refs
 
+    @refs_equal
+    def test_async_func_uses(self):
+        s = 'import a\nasync def f():\n  a'
+        refs = [('a', 'a'), ('a', 'a')]
+        return s, refs
+
     @refs_equal
     def test_func_name_shadows(self):
         s = 'import a\ndef a():\n  pass\n  a'
@@ -41,6 +47,12 @@ class TestFunction:
         refs = [('a', 'a'), ('a', 'a'), ('a', 'a')]
         return s, refs
 
+    @refs_equal
+    def test_func_kw_default_uses(self):
+        s = 'import a\ndef f(*_, c, b=a):\n  pass'
+        refs = [('a', 'a'), ('a', 'a')]
+        return s, refs
+
     @refs_equal
     def test_func_arg_shadows(self):
         s = 'import a\ndef f(a):\n  a'
@@ -90,6 +102,19 @@ class TestFunction:
         refs = [('a', 'a'), ('a', 'a')]
         return s, refs
 
+    @refs_equal
+    def test_lambda_kw_default_uses(self):
+        s = 'import a\nlambda *b, c, d=a: 1'
+        refs = [('a', 'a'), ('a', 'a')]
+        return s, refs
+
+    @pytest.mark.xfail(reason='No reason to do this in the real world.')
+    @refs_equal
+    def test_global_in_outermost_scope(self):
+        s = 'import a\nglobal a'
+        refs = [('a', 'a'), ('a', 'a')]
+        return s, refs
+
     @refs_equal
     def test_global_hits_import_after_inner_shadow(self):
         s = 'import a\ndef f():\n  a = 1\n  def g():\n    global a\n    a'
@@ -154,6 +179,24 @@ class TestComprehension:
         refs = [('a', 'a'), ('a', 'a')]
         return s, refs
 
+    @refs_equal
+    def test_setcomp_uses_in_value(self):
+        s = 'import a\n{a for _ in range(2)}'
+        refs = [('a', 'a'), ('a', 'a')]
+        return s, refs
+
+    @refs_equal
+    def test_dictcomp_uses_in_value(self):
+        s = 'import a\n{a: a for _ in range(2)}'
+        refs = [('a', 'a'), ('a', 'a'), ('a', 'a')]
+        return s, refs
+
+    @refs_equal
+    def test_generator_uses_in_value(self):
+        s = 'import a\n(a for _ in range(2))'
+        refs = [('a', 'a'), ('a', 'a')]
+        return s, refs
+
     @refs_equal
     def test_comp_uses_in_ifs(self):
         s = 'import a\n[_ for _ in range(2) if a]'
